{=========================================================================
  RkLabel Unit

  Enhanced label component that can display its caption in several
  different three dimensional text styles:
    tsNone, tsRaised, tsRecessed, tsShadow

  Developing Custom Delphi 3 Components
  Copyright  1995-1997 by Ray Konopka
=========================================================================}

{$I DCDC.INC}

unit RkLabel;

interface

uses
  SysUtils, Windows, Classes, Graphics, StdCtrls, RkCommon;

type
  TTextStyle = ( tsNone, tsRaised, tsRecessed, tsShadow );

  TRkLabel = class( TLabel )
  private
    FAboutInfo : TRkAboutInfo;
    FTextStyle : TTextStyle;
    FShadowColor : TColor;
    FShadowDepth : Integer;
    procedure SetTextStyle( Value : TTextStyle );
    procedure SetShadowColor( Value : TColor );
    procedure SetShadowDepth( Value : Integer );
    procedure Draw3DText( R : TRect; Flags : Word );
  protected
    procedure Paint; override;
  public
    constructor Create( AOwner : TComponent ); override;
  published
    property About : TRkAboutInfo
      read FAboutInfo
      write FAboutInfo
      stored False;

    property ShadowColor : TColor
      read FShadowColor
      write SetShadowColor
      default clBtnShadow;

    property ShadowDepth : Integer
      read FShadowDepth
      write SetShadowDepth
      default 2;

    property TextStyle : TTextStyle
      read FTextStyle
      write SetTextStyle
      default tsRecessed;
  end;


implementation


{======================}
{== TRkLabel Methods ==}
{======================}

constructor TRkLabel.Create( AOwner : TComponent );
begin
  inherited Create( AOwner );
  FTextStyle := tsRecessed;
  FShadowDepth := 2;
  FShadowColor := clBtnShadow;
end;


procedure TRkLabel.SetShadowColor( Value : TColor );
begin
  if FShadowColor <> Value then
  begin
    FShadowColor := Value;
    Invalidate;
  end;
end;


procedure TRkLabel.SetShadowDepth( Value : Integer );
begin
  if FShadowDepth <> Value then
  begin
    FShadowDepth := Value;
    Invalidate;
  end;
end;


procedure TRkLabel.SetTextStyle( Value : TTextStyle );
begin
  if FTextStyle <> Value then
  begin
    FTextStyle := Value;
    Invalidate;
  end;
end;


procedure TRkLabel.Draw3DText( R : TRect; Flags : Word );
var
  CaptionStz : array[ 0..255 ] of Char;
  TempRct : TRect;
  ULColor : TColor;
  LRColor : TColor;
begin
  with Canvas do
  begin
    StrPCopy( CaptionStz, Caption );

    if WordWrap then
      Flags := Flags or dt_WordBreak;

    if not ShowAccelChar then
      Flags := Flags or dt_NoPrefix;

    Font := Self.Font;

    if FTextStyle in [ tsRecessed, tsRaised ] then
    begin
      if FTextStyle = tsRaised then
      begin
        ULColor := clBtnHighlight;
        LRColor := clBtnShadow;
      end
      else
      begin
        ULColor := clBtnShadow;
        LRColor := clBtnHighlight;
      end;

      TempRct := R;
      OffsetRect( TempRct, 1, 1 );
      Font.Color := LRColor;
      DrawText( Handle, CaptionStz, -1, TempRct, Flags );

      TempRct := R;
      OffsetRect( TempRct, -1, -1 );
      Canvas.Font.Color := ULColor;
      DrawText( Handle, CaptionStz, -1, TempRct, Flags );
    end
    else if FTextStyle = tsShadow then
    begin
      TempRct := R;
      OffsetRect( TempRct, FShadowDepth, FShadowDepth );
      Font.Color := FShadowColor;
      DrawText( Handle, CaptionStz, -1, TempRct, Flags );
    end;

    Font.Color := Self.Font.Color;
    if not Enabled then
      Font.Color := clGrayText;
    DrawText( Handle, CaptionStz, -1, R, Flags );
  end;
end; {= TRkLabel.Draw3DText =}


procedure TRkLabel.Paint;
begin
  with Canvas do
  begin
    if not Transparent then
    begin
      Brush.Color := Self.Color;
      Brush.Style := bsSolid;
      FillRect( ClientRect );                   // Paint area behind label
    end;
    Brush.Style := bsClear;
    Draw3DText( ClientRect, dt_ExpandTabs or TextAlignments[ Alignment ]);
  end;
end; {= TRkLabel.Paint =}


end.
