{=========================================================================
  RkLookup Unit

  This unit implements the TRkLookupDialog component. This component is
  used to display the contents of a dataset, from which the user can
  select a record in that dataset.  The dialog also provides keyboard
  searching.

  Developing Custom Delphi 3 Components
  Copyright  1995-1997 by Ray Konopka
=========================================================================}

{$I DCDC.INC}

unit RkLookup;

interface

uses
  Classes, Graphics, Forms, DB, RkCommon;

type
  TRkLookupDialog = class( TComponent )
  private
    FAboutInfo : TRkAboutInfo;
    FBorderStyle : TFormBorderStyle;
    FCaption : string;
    FDataset : TDataset;
    FHeight : Integer;
    FFont : TFont;
    FNumbersOnly : Boolean;
    FSearchField : string;
    FWidth : Integer;
    procedure SetFont( Value : TFont );
  protected
    procedure Notification( AComponent : TComponent;
                            Operation : TOperation ); override;
  public
    constructor Create( AOwner : TComponent ); override;
    destructor Destroy; override;
    function Execute : Boolean;
  published
    property About : TRkAboutInfo
      read FAboutInfo
      write FAboutInfo
      stored False;

    property BorderStyle : TFormBorderStyle
      read FBorderStyle
      write FBorderStyle
      default bsSizeable;

    property Caption : string
      read FCaption
      write FCaption;

    property Dataset : TDataset
      read FDataset
      write FDataset;

    property Font : TFont
      read FFont
      write SetFont;

    property Height : Integer
      read FHeight
      write FHeight
      default 300;

    property NumbersOnly : Boolean
      read FNumbersOnly
      write FNumbersOnly;

    property SearchField : string
      read FSearchField
      write FSearchField;

    property Width : Integer
      read FWidth
      write FWidth
      default 350;
  end;


implementation

uses
  Windows, Controls, RkLookFm;


{=============================}
{== TRkLookupDialog Methods ==}
{=============================}

constructor TRkLookupDialog.Create( AOwner : TComponent );
begin
  inherited Create( AOwner );
  FHeight := 300;
  FWidth := 350;
  FBorderStyle := bsSizeable;
  FFont := TFont.Create;
  if Owner is TForm then                          // If Owner is a form...
    FFont.Assign( TForm( Owner ).Font ); // Use the form's font by default
end;


destructor TRkLookupDialog.Destroy;
begin
  FFont.Free;
  inherited Destroy;
end;


procedure TRkLookupDialog.Notification( AComponent : TComponent;
                                        Operation : TOperation);
begin
  inherited Notification( AComponent, Operation );

  if ( Operation = opRemove ) and ( AComponent = FDataset ) then
    FDataset := nil;
end;


procedure TRkLookupDialog.SetFont( Value : TFont );
begin
  FFont.Assign( Value );
end;


function TRkLookupDialog.Execute : Boolean;
begin
  // Dynamically create the Lookup form RkLookupForm
  // declared in the RkLookFm unit
  RkLookupForm := TRkLookupForm.Create( Application );
  try
    // Initialize properties of lookup form
    RkLookupForm.BorderStyle := FBorderStyle;
    RkLookupForm.Width := FWidth;
    RkLookupForm.Height := FHeight;
    RkLookupForm.Font := FFont;
    RkLookupForm.Caption := FCaption;
    RkLookupForm.NumbersOnly := FNumbersOnly;
    RkLookupForm.LblPrompt.Caption := 'Search for ' + FSearchField;

    // Set the field to be used for keyboard searching
    RkLookupForm.SearchField := FSearchField;
    // Set dataset used to populate the grid
    RkLookupForm.SrcLookup.Dataset := FDataset;

    Result := RkLookupForm.ShowModal = idOK;     // Display the dialog box
  finally
    RkLookupForm.Free;                    // Don't forget to free the form
  end;
end;


end.
